#!/bin/sh
make -f Makefile.cvs

[ ! -f Makefile ] || make clean
export kde_htmldir=/opt/trinity/usr/share/doc/tde/HTML
export TDEDIRS=/usr:/opt/trinity
sh ./configure --prefix=/opt/trinity

make
make install

mv /opt/trinity/share/applnk/Utilities/knutclient.desktop /opt/trinity/share/applications/tde/

